==> icedtea-web-1.0.1.tar.gz: icedtea-web-1.0.1/netx/net/sourceforge/jnlp/security/JNLPAuthenticator.java <==
/* JNLPAuthenticator
   Copyright (C) 2008  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */

package net.sourceforge.jnlp.security;

import java.net.Authenticator;
import java.net.PasswordAuthentication;

public class JNLPAuthenticator extends Authenticator {

    public PasswordAuthentication getPasswordAuthentication() {

        // No security check is required here, because the only way to set
        // parameters for which auth info is needed
        // (Authenticator:requestPasswordAuthentication()), has a security check

        String type = this.getRequestorType() == RequestorType.PROXY ? "proxy" : "web";

        // request auth info from user
        PasswordAuthenticationDialog pwDialog = new PasswordAuthenticationDialog();
        PasswordAuthentication auth = pwDialog.askUser(this.getRequestingHost(), this.getRequestingPort(), this.getRequestingPrompt(), type);

        // send it along
        return auth;
    }

}

==> icedtea-web_1.5.orig.tar.gz: icedtea-web-1.5/netx/net/sourceforge/jnlp/security/JNLPAuthenticator.java <==
/* JNLPAuthenticator
   Copyright (C) 2008  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */

package net.sourceforge.jnlp.security;

import java.net.Authenticator;
import java.net.PasswordAuthentication;

public class JNLPAuthenticator extends Authenticator {

    @Override
    public PasswordAuthentication getPasswordAuthentication() {

        // No security check is required here, because the only way to set
        // parameters for which auth info is needed
        // (Authenticator:requestPasswordAuthentication()), has a security check

        String type = this.getRequestorType() == RequestorType.PROXY ? "proxy" : "web";

        String host = getRequestingHost();
        int port = getRequestingPort();
        String prompt = getRequestingPrompt();

        Object[] response = SecurityDialogs.showAuthenicationPrompt(host, port, prompt, type);
        if (response == null) {
            return null;
        } else {
            return new PasswordAuthentication((String) response[0], (char[]) response[1]);
        }
    }

}
